TEMPLATE = """
# This file was generated by FigmaFlet by Benit Mulindwa
# https://github.com/Benitmulindwa/FigmaFlet

import flet as ft

def main(page: ft.Page):
    page.padding=0
    page.fonts={{font_urls}}
    page.add(
       ft.Stack([
        {{ elements }}
        ])
    )
ft.app(target=main)
"""
